Package: paws.end.user.computing
Title: 'Amazon Web Services' End User Computing Services
Version: 0.10.0
Authors@R: c(
    person("David", "Kretch", , "david.kretch@gmail.com", role = "aut"),
    person("Adam", "Banker", , "adam.banker39@gmail.com", role = "aut"),
    person("Dyfan", "Jones", , "dyfan.r.jones@gmail.com", role = "cre"),
    person("Amazon.com, Inc.", role = "cph")
  )
Description: Interface to 'Amazon Web Services' end user computing
    services, including collaborative document editing, mobile intranet,
    and more <https://aws.amazon.com/>.
License: Apache License (>= 2.0)
URL: https://github.com/paws-r/paws,
        https://paws-r.r-universe.dev/paws.end.user.computing,
        https://www.paws-r-sdk.com
BugReports: https://github.com/paws-r/paws/issues
Imports: paws.common (>= 0.8.0)
Suggests: testthat
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
Collate: 'appstream_service.R' 'appstream_interfaces.R'
        'appstream_operations.R' 'chatbot_service.R'
        'chatbot_interfaces.R' 'chatbot_operations.R'
        'ivschat_service.R' 'ivschat_interfaces.R'
        'ivschat_operations.R' 'reexports_paws.common.R'
        'workdocs_service.R' 'workdocs_interfaces.R'
        'workdocs_operations.R' 'workmail_service.R'
        'workmail_interfaces.R' 'workmail_operations.R'
        'workmailmessageflow_service.R'
        'workmailmessageflow_interfaces.R'
        'workmailmessageflow_operations.R' 'workspaces_service.R'
        'workspaces_interfaces.R' 'workspaces_operations.R'
        'workspacesweb_service.R' 'workspacesweb_interfaces.R'
        'workspacesweb_operations.R'
NeedsCompilation: no
Packaged: 2026-05-29 17:22:04 UTC; dyfan
Author: David Kretch [aut],
  Adam Banker [aut],
  Dyfan Jones [cre],
  Amazon.com, Inc. [cph]
Maintainer: Dyfan Jones <dyfan.r.jones@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-30 05:11:09 UTC
Built: R 4.6.0; ; 2026-05-30 05:41:42 UTC; unix
