# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common populate
#' @include chatbot_service.R
NULL

.chatbot$associate_to_configuration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Resource = structure(logical(0), tags = list(type = "string")), ChatConfiguration = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$associate_to_configuration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$create_chime_webhook_configuration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(WebhookDescription = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), WebhookUrl = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), IamRoleArn = structure(logical(0), tags = list(type = "string")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$create_chime_webhook_configuration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(WebhookConfiguration = structure(list(WebhookDescription = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), IamRoleArn = structure(logical(0), tags = list(type = "string")), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), State = structure(logical(0), tags = list(type = "string")), StateReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$create_custom_action_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Definition = structure(list(CommandText = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), AliasName = structure(logical(0), tags = list(type = "string")), Attachments = structure(list(structure(list(NotificationType = structure(logical(0), tags = list(type = "string")), ButtonText = structure(logical(0), tags = list(type = "string")), Criteria = structure(list(structure(list(Operator = structure(logical(0), tags = list(type = "string")), VariableName = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), Variables = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "list")), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), ClientToken = structure(logical(0), tags = list(idempotencyToken = TRUE, type = "string")), ActionName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$create_custom_action_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(CustomActionArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$create_microsoft_teams_channel_configuration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChannelId = structure(logical(0), tags = list(type = "string")), ChannelName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), TeamId = structure(logical(0), tags = list(type = "string")), TeamName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), TenantId = structure(logical(0), tags = list(type = "string")), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), IamRoleArn = structure(logical(0), tags = list(type = "string")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), GuardrailPolicyArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE)), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$create_microsoft_teams_channel_configuration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChannelConfiguration = structure(list(ChannelId = structure(logical(0), tags = list(type = "string")), ChannelName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), TeamId = structure(logical(0), tags = list(type = "string")), TeamName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), TenantId = structure(logical(0), tags = list(type = "string")), ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), IamRoleArn = structure(logical(0), tags = list(type = "string")), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), GuardrailPolicyArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE)), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), State = structure(logical(0), tags = list(type = "string")), StateReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$create_slack_channel_configuration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(SlackTeamId = structure(logical(0), tags = list(type = "string")), SlackChannelId = structure(logical(0), tags = list(type = "string")), SlackChannelName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), IamRoleArn = structure(logical(0), tags = list(type = "string")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), GuardrailPolicyArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE)), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$create_slack_channel_configuration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChannelConfiguration = structure(list(SlackTeamName = structure(logical(0), tags = list(type = "string")), SlackTeamId = structure(logical(0), tags = list(type = "string")), SlackChannelId = structure(logical(0), tags = list(type = "string")), SlackChannelName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), IamRoleArn = structure(logical(0), tags = list(type = "string")), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), GuardrailPolicyArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE)), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), State = structure(logical(0), tags = list(type = "string")), StateReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_chime_webhook_configuration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChatConfigurationArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_chime_webhook_configuration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_custom_action_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(CustomActionArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_custom_action_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_microsoft_teams_channel_configuration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChatConfigurationArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_microsoft_teams_channel_configuration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_microsoft_teams_configured_team_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(TeamId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_microsoft_teams_configured_team_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_microsoft_teams_user_identity_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), UserId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_microsoft_teams_user_identity_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_slack_channel_configuration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChatConfigurationArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_slack_channel_configuration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_slack_user_identity_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), SlackTeamId = structure(logical(0), tags = list(type = "string")), SlackUserId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_slack_user_identity_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_slack_workspace_authorization_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(SlackTeamId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$delete_slack_workspace_authorization_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$describe_chime_webhook_configurations_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(MaxResults = structure(logical(0), tags = list(type = "integer", box = TRUE)), NextToken = structure(logical(0), tags = list(type = "string")), ChatConfigurationArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$describe_chime_webhook_configurations_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(NextToken = structure(logical(0), tags = list(type = "string")), WebhookConfigurations = structure(list(structure(list(WebhookDescription = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), IamRoleArn = structure(logical(0), tags = list(type = "string")), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), State = structure(logical(0), tags = list(type = "string")), StateReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$describe_slack_channel_configurations_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(MaxResults = structure(logical(0), tags = list(type = "integer", box = TRUE)), NextToken = structure(logical(0), tags = list(type = "string")), ChatConfigurationArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$describe_slack_channel_configurations_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(NextToken = structure(logical(0), tags = list(type = "string")), SlackChannelConfigurations = structure(list(structure(list(SlackTeamName = structure(logical(0), tags = list(type = "string")), SlackTeamId = structure(logical(0), tags = list(type = "string")), SlackChannelId = structure(logical(0), tags = list(type = "string")), SlackChannelName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), IamRoleArn = structure(logical(0), tags = list(type = "string")), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), GuardrailPolicyArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE)), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), State = structure(logical(0), tags = list(type = "string")), StateReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$describe_slack_user_identities_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), NextToken = structure(logical(0), tags = list(type = "string")), MaxResults = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$describe_slack_user_identities_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(SlackUserIdentities = structure(list(structure(list(IamRoleArn = structure(logical(0), tags = list(type = "string")), ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), SlackTeamId = structure(logical(0), tags = list(type = "string")), SlackUserId = structure(logical(0), tags = list(type = "string")), AwsUserIdentity = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$describe_slack_workspaces_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(MaxResults = structure(logical(0), tags = list(type = "integer", box = TRUE)), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$describe_slack_workspaces_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(SlackWorkspaces = structure(list(structure(list(SlackTeamId = structure(logical(0), tags = list(type = "string")), SlackTeamName = structure(logical(0), tags = list(type = "string")), State = structure(logical(0), tags = list(type = "string")), StateReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$disassociate_from_configuration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Resource = structure(logical(0), tags = list(type = "string")), ChatConfiguration = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$disassociate_from_configuration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$get_account_preferences_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$get_account_preferences_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(AccountPreferences = structure(list(UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE)), TrainingDataCollectionEnabled = structure(logical(0), tags = list(type = "boolean", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$get_custom_action_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(CustomActionArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$get_custom_action_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(CustomAction = structure(list(CustomActionArn = structure(logical(0), tags = list(type = "string")), Definition = structure(list(CommandText = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), AliasName = structure(logical(0), tags = list(type = "string")), Attachments = structure(list(structure(list(NotificationType = structure(logical(0), tags = list(type = "string")), ButtonText = structure(logical(0), tags = list(type = "string")), Criteria = structure(list(structure(list(Operator = structure(logical(0), tags = list(type = "string")), VariableName = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), Variables = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "list")), ActionName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$get_microsoft_teams_channel_configuration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChatConfigurationArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$get_microsoft_teams_channel_configuration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChannelConfiguration = structure(list(ChannelId = structure(logical(0), tags = list(type = "string")), ChannelName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), TeamId = structure(logical(0), tags = list(type = "string")), TeamName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), TenantId = structure(logical(0), tags = list(type = "string")), ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), IamRoleArn = structure(logical(0), tags = list(type = "string")), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), GuardrailPolicyArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE)), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), State = structure(logical(0), tags = list(type = "string")), StateReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$list_associations_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChatConfiguration = structure(logical(0), tags = list(type = "string")), MaxResults = structure(logical(0), tags = list(type = "integer", box = TRUE)), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$list_associations_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Associations = structure(list(structure(list(Resource = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$list_custom_actions_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(MaxResults = structure(logical(0), tags = list(type = "integer", box = TRUE)), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$list_custom_actions_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(CustomActions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$list_microsoft_teams_channel_configurations_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(MaxResults = structure(logical(0), tags = list(type = "integer", box = TRUE)), NextToken = structure(logical(0), tags = list(type = "string")), TeamId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$list_microsoft_teams_channel_configurations_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(NextToken = structure(logical(0), tags = list(type = "string")), TeamChannelConfigurations = structure(list(structure(list(ChannelId = structure(logical(0), tags = list(type = "string")), ChannelName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), TeamId = structure(logical(0), tags = list(type = "string")), TeamName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), TenantId = structure(logical(0), tags = list(type = "string")), ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), IamRoleArn = structure(logical(0), tags = list(type = "string")), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), GuardrailPolicyArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE)), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), State = structure(logical(0), tags = list(type = "string")), StateReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$list_microsoft_teams_configured_teams_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(MaxResults = structure(logical(0), tags = list(type = "integer", box = TRUE)), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$list_microsoft_teams_configured_teams_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ConfiguredTeams = structure(list(structure(list(TenantId = structure(logical(0), tags = list(type = "string")), TeamId = structure(logical(0), tags = list(type = "string")), TeamName = structure(logical(0), tags = list(type = "string")), State = structure(logical(0), tags = list(type = "string")), StateReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$list_microsoft_teams_user_identities_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), NextToken = structure(logical(0), tags = list(type = "string")), MaxResults = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$list_microsoft_teams_user_identities_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(TeamsUserIdentities = structure(list(structure(list(IamRoleArn = structure(logical(0), tags = list(type = "string")), ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), TeamId = structure(logical(0), tags = list(type = "string")), UserId = structure(logical(0), tags = list(type = "string")), AwsUserIdentity = structure(logical(0), tags = list(type = "string")), TeamsChannelId = structure(logical(0), tags = list(type = "string")), TeamsTenantId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$list_tags_for_resource_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ResourceARN = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$list_tags_for_resource_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$tag_resource_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ResourceARN = structure(logical(0), tags = list(type = "string")), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$tag_resource_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$untag_resource_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ResourceARN = structure(logical(0), tags = list(type = "string")), TagKeys = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$untag_resource_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$update_account_preferences_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE)), TrainingDataCollectionEnabled = structure(logical(0), tags = list(type = "boolean", box = TRUE))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$update_account_preferences_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(AccountPreferences = structure(list(UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE)), TrainingDataCollectionEnabled = structure(logical(0), tags = list(type = "boolean", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$update_chime_webhook_configuration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), WebhookDescription = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), WebhookUrl = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), IamRoleArn = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$update_chime_webhook_configuration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(WebhookConfiguration = structure(list(WebhookDescription = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), IamRoleArn = structure(logical(0), tags = list(type = "string")), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), State = structure(logical(0), tags = list(type = "string")), StateReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$update_custom_action_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(CustomActionArn = structure(logical(0), tags = list(type = "string")), Definition = structure(list(CommandText = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), AliasName = structure(logical(0), tags = list(type = "string")), Attachments = structure(list(structure(list(NotificationType = structure(logical(0), tags = list(type = "string")), ButtonText = structure(logical(0), tags = list(type = "string")), Criteria = structure(list(structure(list(Operator = structure(logical(0), tags = list(type = "string")), VariableName = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), Variables = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$update_custom_action_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(CustomActionArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$update_microsoft_teams_channel_configuration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), ChannelId = structure(logical(0), tags = list(type = "string")), ChannelName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), IamRoleArn = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), GuardrailPolicyArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$update_microsoft_teams_channel_configuration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChannelConfiguration = structure(list(ChannelId = structure(logical(0), tags = list(type = "string")), ChannelName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), TeamId = structure(logical(0), tags = list(type = "string")), TeamName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), TenantId = structure(logical(0), tags = list(type = "string")), ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), IamRoleArn = structure(logical(0), tags = list(type = "string")), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), GuardrailPolicyArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE)), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), State = structure(logical(0), tags = list(type = "string")), StateReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$update_slack_channel_configuration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), SlackChannelId = structure(logical(0), tags = list(type = "string")), SlackChannelName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), IamRoleArn = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), GuardrailPolicyArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.chatbot$update_slack_channel_configuration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ChannelConfiguration = structure(list(SlackTeamName = structure(logical(0), tags = list(type = "string")), SlackTeamId = structure(logical(0), tags = list(type = "string")), SlackChannelId = structure(logical(0), tags = list(type = "string")), SlackChannelName = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), ChatConfigurationArn = structure(logical(0), tags = list(type = "string")), IamRoleArn = structure(logical(0), tags = list(type = "string")), SnsTopicArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), ConfigurationName = structure(logical(0), tags = list(type = "string")), LoggingLevel = structure(logical(0), tags = list(type = "string")), GuardrailPolicyArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), UserAuthorizationRequired = structure(logical(0), tags = list(type = "boolean", box = TRUE)), Tags = structure(list(structure(list(TagKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), State = structure(logical(0), tags = list(type = "string")), StateReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}
