# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common populate
#' @include workmailmessageflow_service.R
NULL

.workmailmessageflow$get_raw_message_content_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(messageId = structure(logical(0), tags = list(location = "uri", locationName = "messageId", type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.workmailmessageflow$get_raw_message_content_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(messageContent = structure(logical(0), tags = list(type = "blob", streaming = TRUE))), tags = list(type = "structure", payload = "messageContent"))
  return(populate(args, shape))
}

.workmailmessageflow$put_raw_message_content_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(messageId = structure(logical(0), tags = list(location = "uri", locationName = "messageId", type = "string")), content = structure(list(s3Reference = structure(list(bucket = structure(logical(0), tags = list(type = "string")), key = structure(logical(0), tags = list(type = "string")), objectVersion = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.workmailmessageflow$put_raw_message_content_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}
