% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/appstream_operations.R
\name{appstream_associate_app_block_builder_app_block}
\alias{appstream_associate_app_block_builder_app_block}
\title{Associates the specified app block builder with the specified app block}
\usage{
appstream_associate_app_block_builder_app_block(
  AppBlockArn,
  AppBlockBuilderName
)
}
\arguments{
\item{AppBlockArn}{[required] The ARN of the app block.}

\item{AppBlockBuilderName}{[required] The name of the app block builder.}
}
\description{
Associates the specified app block builder with the specified app block.

See \url{https://www.paws-r-sdk.com/docs/appstream_associate_app_block_builder_app_block/} for full documentation.
}
\keyword{internal}
