% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/workspaces_operations.R
\name{workspaces_associate_connection_alias}
\alias{workspaces_associate_connection_alias}
\title{Associates the specified connection alias with the specified directory
to enable cross-Region redirection}
\usage{
workspaces_associate_connection_alias(AliasId, ResourceId)
}
\arguments{
\item{AliasId}{[required] The identifier of the connection alias.}

\item{ResourceId}{[required] The identifier of the directory to associate the connection alias with.}
}
\description{
Associates the specified connection alias with the specified directory to enable cross-Region redirection. For more information, see \href{https://docs.aws.amazon.com/workspaces/latest/adminguide/cross-region-redirection.html}{Cross-Region Redirection for Amazon WorkSpaces}.

See \url{https://www.paws-r-sdk.com/docs/workspaces_associate_connection_alias/} for full documentation.
}
\keyword{internal}
