% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/workspaces_operations.R
\name{workspaces_describe_workspace_directories}
\alias{workspaces_describe_workspace_directories}
\title{Describes the available directories that are registered with Amazon
WorkSpaces}
\usage{
workspaces_describe_workspace_directories(
  DirectoryIds = NULL,
  WorkspaceDirectoryNames = NULL,
  Limit = NULL,
  NextToken = NULL,
  Filters = NULL
)
}
\arguments{
\item{DirectoryIds}{The identifiers of the directories. If the value is null, all directories are retrieved.}

\item{WorkspaceDirectoryNames}{The names of the WorkSpace directories.}

\item{Limit}{The maximum number of directories to return.}

\item{NextToken}{If you received a \code{NextToken} from a previous call that was paginated, provide this token to receive the next set of results.}

\item{Filters}{The filter condition for the WorkSpaces.}
}
\description{
Describes the available directories that are registered with Amazon WorkSpaces.

See \url{https://www.paws-r-sdk.com/docs/workspaces_describe_workspace_directories/} for full documentation.
}
\keyword{internal}
