% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/workspacesweb_operations.R
\name{workspacesweb_create_user_access_logging_settings}
\alias{workspacesweb_create_user_access_logging_settings}
\title{Creates a user access logging settings resource that can be associated
with a web portal}
\usage{
workspacesweb_create_user_access_logging_settings(
  kinesisStreamArn,
  tags = NULL,
  clientToken = NULL
)
}
\arguments{
\item{kinesisStreamArn}{[required] The ARN of the Kinesis stream.}

\item{tags}{The tags to add to the user settings resource. A tag is a key-value pair.}

\item{clientToken}{A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token returns the result from the original successful request.

If you do not specify a client token, one is automatically generated by the Amazon Web Services SDK.}
}
\description{
Creates a user access logging settings resource that can be associated with a web portal.

See \url{https://www.paws-r-sdk.com/docs/workspacesweb_create_user_access_logging_settings/} for full documentation.
}
\keyword{internal}
