% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/workdocs_operations.R
\name{workdocs_initiate_document_version_upload}
\alias{workdocs_initiate_document_version_upload}
\title{Creates a new document object and version object}
\usage{
workdocs_initiate_document_version_upload(
  AuthenticationToken = NULL,
  Id = NULL,
  Name = NULL,
  ContentCreatedTimestamp = NULL,
  ContentModifiedTimestamp = NULL,
  ContentType = NULL,
  DocumentSizeInBytes = NULL,
  ParentFolderId = NULL
)
}
\arguments{
\item{AuthenticationToken}{Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.}

\item{Id}{The ID of the document.}

\item{Name}{The name of the document.}

\item{ContentCreatedTimestamp}{The timestamp when the content of the document was originally created.}

\item{ContentModifiedTimestamp}{The timestamp when the content of the document was modified.}

\item{ContentType}{The content type of the document.}

\item{DocumentSizeInBytes}{The size of the document, in bytes.}

\item{ParentFolderId}{The ID of the parent folder.}
}
\description{
Creates a new document object and version object.

See \url{https://www.paws-r-sdk.com/docs/workdocs_initiate_document_version_upload/} for full documentation.
}
\keyword{internal}
